@@ -6,7 +6,7 @@ package threads; # but in fact we're masquerading as threads.pm
 # Set flag to indicate that we're not really the original threads implementation
 # Be strict from now on
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 $threads        = $threads        = 1; # twice to avoid warnings
 $forks::threads = $forks::threads = 1; # twice to avoid warnings
 use strict;
@@ -987,8 +987,8 @@ sub _tie {
 
     my $module = $remote->{'module'};
     if (eval "use $module; 1") {
-        eval $remote->{'eval'};
-        if (my $use = $remote->{'use'}) {
+        eval $remote->{'eval'} if defined( $remote->{'eval'} );
+        if (my $use = $remote->{'use'} || '') {
             if (ref($use)) {
                 eval "use $_" foreach @$use;
             } else {
